@@ -1,7 +1,6 @@
 from math import isnan
 
-import ramda as R
-
+from ..equals import equals
 from ._helper import getAttribute
 from ._isFunction import _isFunction
 from ._isNumber import _isNumber
@@ -17,7 +16,7 @@ def _indexOf(arr, a, idx):
     return arr.indexOf(a, idx)
 
   while idx < len(arr):
-    if R.equals(arr[idx], a):
+    if equals(arr[idx], a):
       return idx
     idx += 1
   return -1
