@@ -4,7 +4,7 @@ from ._xfBase import XfBase
 
 class XMap(XfBase):
   def __init__(self, f, xf):
-    self.xf = xf
+    super().__init__(xf)
     self.f = f
 
   def step(self, result, _input):
